package com.ningdatech.pmapi.projectlib.handler;

import com.ningdatech.pmapi.common.constant.CommonConstant;
import com.ningdatech.pmapi.projectlib.enumeration.StepStatusEnum;
import com.ningdatech.pmapi.projectlib.model.entity.Project;
import com.ningdatech.pmapi.projectlib.model.vo.ProcessDetailVO;
import com.ningdatech.pmapi.projectlib.service.IProjectService;
import org.springframework.beans.factory.annotation.Autowired;

import java.time.LocalDateTime;

/**
 * 项目申报处理
 *
 * @author CMM
 * @since 2023/02/24 14:35
 */

public class ProjectDeclareHandle extends AbstractProcessBusinessHandler{

    @Autowired
    private IProjectService projectService;

    /**
     * 设置该业务前缀
     */
    private static final String PREFIX = CommonConstant.PROJECT_DECLARE_PREFIX;

    public ProjectDeclareHandle(){
        setPrefix(PREFIX);
    }

    @Override
    ProcessDetailVO businessHandle(Long projectId) {
        // 因为此时在项目库中的项目，都是已经申报过的项目，所以直接设置环节状态为已完成
        ProcessDetailVO processDetailVO = new ProcessDetailVO();
        processDetailVO.setStepStatus(StepStatusEnum.COMPLETED);
        // 项目库中查出申报完成时间
        Project project = projectService.getById(projectId);
        LocalDateTime createOn = project.getCreateOn();
        processDetailVO.setFinishTime(createOn);
        return processDetailVO;
    }
}
