package com.ningdatech.pmapi.projectlib.handler;

import java.time.LocalDateTime;

import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.ningdatech.pmapi.projectlib.enumeration.InstTypeEnum;
import com.ningdatech.pmapi.projectlib.model.entity.ProjectInst;
import com.ningdatech.pmapi.projectlib.service.IProjectInstService;

import com.ningdatech.pmapi.common.constant.CommonConstant;
import com.ningdatech.pmapi.projectlib.enumeration.StepStatusEnum;
import com.ningdatech.pmapi.projectlib.model.vo.ProcessDetailVO;
import com.wflow.workflow.bean.vo.ProcessProgressVo;
import com.wflow.workflow.enums.ProcessStatusEnum;
import com.wflow.workflow.service.ProcessInstanceService;
import org.springframework.stereotype.Component;

/**
 * 单位内部审核处理
 *
 * @author CMM
 * @since 2023/02/24 14:35
 */
@Component
public class UnitInnerAuditHandle extends AbstractProcessBusinessHandler{

    private final IProjectInstService projectInstService;

    private final ProcessInstanceService processInstanceService;

    /**
     * 设置该业务前缀
     */
    private static final String PREFIX = CommonConstant.UNIT_INNER_AUDIT_PREFIX;

    public UnitInnerAuditHandle(IProjectInstService projectInstService, ProcessInstanceService processInstanceService){
        setPrefix(PREFIX);
        this.projectInstService = projectInstService;
        this.processInstanceService = processInstanceService;
    }

    @Override
    ProcessDetailVO businessHandle(Long projectId) {
        ProcessDetailVO processDetailVO = new ProcessDetailVO();
        // 根据项目ID查询出单位内部审核流程的流程状态
        // 注意：已经在项目库中的项目，一定是已经开始的项目
        ProjectInst projectInst = projectInstService.getOne(Wrappers.lambdaQuery(ProjectInst.class)
                .eq(ProjectInst::getProjectId, projectId)
                .eq(ProjectInst::getInstType, InstTypeEnum.UNIT_INNER_AUDIT.getCode()));
        String instCode = projectInst.getInstCode();
        ProcessProgressVo instanceDetail = processInstanceService.getProgressInstanceDetail(null, instCode);
        String status = instanceDetail.getStatus();
        if (ProcessStatusEnum.UNDER_REVIEW.getDesc().equals(status)){
            processDetailVO.setStepStatus(StepStatusEnum.ON_GOING);
        } else if (ProcessStatusEnum.BE_REJECTED.getDesc().equals(status)) {
            processDetailVO.setStepStatus(StepStatusEnum.REJECTED);
        } else if (ProcessStatusEnum.APPROVED.getDesc().equals(status)) {
            processDetailVO.setStepStatus(StepStatusEnum.COMPLETED);
        }
        // 项目库中查出申报完成时间
        LocalDateTime finishTime = processDetailVO.getFinishTime();
        processDetailVO.setFinishTime(finishTime);
        return processDetailVO;
    }
}
